# @(#)help.tcl	1.5  97/12/23

# Copyright (c) Communications Research Centre, Government of Canada 1997. 
# All rights reserved.
# 
# License is granted to copy and use this software, for research and
# evaluation purposes, provided that the Communications Research Centre
# is acknowledged in all documentation pertaining to any such copy or
# use. The Communications Research Centre grants no other licenses
# expressed or implied. Title, ownership rights, and intellectual
# property rights in the software shall remain with the Communications
# Research Centre.  The Centre's name and the Government of Canada
# should not be used in any advertising without written permission.
# 
# THE COMMUNICATIONS RESEARCH CENTRE MAKES NO REPRESENTATIONS CONCERNING
# EITHER THE MERCHANTABILITY OF THIS SOFTWARE OR THE SUITABILITY OF
# THIS SOFTWARE FOR ANY PARTICULAR PURPOSE.  The software is provided
# "as is" without express or implied warranty of any kind.
# 
# These notices must be retained in any copies of any part of this
# software.
# 


proc helpme topic {

   if {[winfo exists .help] != 0} {
      destroy .help
      }
      
   toplevel .help
   wm title .help "MPoll help"
   
   frame .help.top
   pack .help.top -side "top" -fill both -expand yes
   
   text .help.top.textwin \
      -wrap "none" \
      -width 60 \
      -height 16 \
      -yscrollcommand ".help.top.scroll set" \

   scrollbar .help.top.scroll \
      -orient vertical \
      -command ".help.top.textwin yview"

   pack .help.top.scroll -side right -fill y
   pack .help.top.textwin -expand yes -fill both

   if {$topic == "about"} {
      help_about
   } elseif {$topic == "topics"} {
      help_topics
   } elseif {$topic == "quest"} {
      help_quest
   } elseif {$topic == "create"} {
      help_create
   } elseif {$topic == "results"} {
      help_results
   } elseif {$topic == "string-results"} {
      help_string_results
   } elseif {$topic == "monitor"} {
      help_monitor
   } elseif {$topic == "log"} {
      help_log
   } elseif {$topic == "members"} {
      help_members
   } else {
   .help.top.textwin insert 0.0 \
   {ERROR: unknown topic for help request on: $topic.}   
      }

   .help.top.textwin configure -state disabled

   # bottom buttons are created now

   frame .help.bottomframe
   pack .help.bottomframe -side "bottom"  -fill  "x" -pady 3

   button .help.bottomframe.dismiss \
      -text "Dismiss" \
      -command {destroy .help}
   pack .help.bottomframe.dismiss -side  "right"
}


proc help_about {} {

.help.top.textwin insert 0.0 \
{"MPoll" is a real-time opinion polling and rating collection tool
that uses multicasting to distribute questions and responses to all
the participants. "MPoll" was developed by Andrew Patrick at the
Communications Research Centre (CRC) in Ottawa, Canada, as part of
the MERCI project on Collaborative Work Tools.

For more information about MPoll, see
   http://debra.dgbt.doc.ca/mbone/mpoll/
or contact
   Andrew.Patrick@crc.doc.ca
   
"MPoll" is Copyright (c) Communications Research Centre, Government
of Canada, 1997.  All Rights Reserved. Contact the author for
distribution information.
}
}


proc help_topics {} {

.help.top.textwin insert 0.0 \
{This is the main topic window for MPoll.  A list of question topics
will appear on the left hand side when users create questions.   To
select a topic, single-click Button 1 (left) on the topic. The
buttons on the right side then allow you to:

   - view the question and make your response
   - view the results
   - create a new question
   - delete a question that you created

Further help is available when each function is used.

In addition, MPoll provides a Traffic Monitor that displays the
incoming and outgoing traffic for this MPoll session. Also, the
Members button will display of list of people currently running MPoll
for this session.

The Save Results button will write a text file in your home directory
that summarizes all the questions and results.  This file is human-
readable and could also be used as input to a data analysis program.

The Quit button will stop MPoll.  MPoll creates a cache file in your
home directory to save the questions from your last MPoll session so
your questions and responses are reloaded automatically.

Shortcuts:
   - double-click Button 1 (left) on a topic to view a question
   - single-click Button 3 (right) on a topic to view the results
   
}
}

proc help_quest {} {

   .help.top.textwin insert 0.0 \
{This window displays the question for a topic and all the available
responses.   You answer a question by clicking Button 1 (left) on one
of the response buttons, and then pressing the "Submit Your Response"
button.  Your response is immediately sent to everyone who is using
this MPoll session, and periodically repeated for late joiners as long
as you have MPoll running.

Also displayed are the author and creation date for this
question.  In addition, the Response Life Time (the time that a
response will be considered valid when calculating the results) is
shown, and a message will appear if your previous response has
expired.  

You can view the results received so for by pressing the "View
Results" button.

}
}

proc help_create {} {

   .help.top.textwin insert 0.0 \
{This window is used to create new questions. When a question is
created, it is sent to all users immediately and repeated
periodically for late joiners as long as you have MPoll running.  The
fields required to create a question are:

- a short "question topic", which is used for the topic display in
   the main window
   
- the poll question that you want users to answer.  Make sure that
   your question is understandable.

- the possible responses for your question.  You can offer up to 10
   possible responses.  Make sure that each response is
   understandable.  (Shortcut: use TAB to move between responses.)

There are also two question options:

- the number of responses allowed.  

   Simple multiple-choice questions only allow one response (e.g.,
   "Yes" or "No"), while other questions may allow more than one
   response (e.g., all the opinions you agree with).

- the response life time, expressed in minutes.  

   For some question, such as collecting quality ratings during an
   MBone session, you may only be interested in recent responses. 
   Here you might select a short Response Life Time (e.g., 15
   minutes) so only recent responses are counted in the results.
   When a response is older than the response life time, it will be
   deleted from the results and the users will be reminded to
   answer the question again.
   
   For other questions you may want to include all responses made
   during an MPoll session.  A Response Life Time of 0 (zero)
   represents an infinite life time, so responses never expire.

Once you have entered all the fields and selected the options, press
the "Create Question" button.
}
}

proc help_results {} {

   .help.top.textwin insert 0.0 \
{This window presents a graphical display of the responses received
for a question.  Each data bar represents the precentage of users
giving that response, and the actual response count is shown at the
top of the bar.  In addition, the total number of responses is shown
at the top of the graph.

The results display is updated automatically at regular intervals.
}
}


proc help_string_results {} {

   .help.top.textwin insert 0.0 \
{This window presents a text display of the responses received for a
question.  Each response to the question is listed in the window,
separated from the previous response by "---" characters.

To provide stability during reading of the responses, the results
display is not updated automatically and you should press the
"Update" button to get the latest responses.
}
}


proc help_monitor {} {

   .help.top.textwin insert 0.0 \
{The Traffic Monitor displays the incoming and outgoing multicast
traffic for this MPoll session.  Traffic that is displayed here
includes:

   - incoming questions from other users
   - incoming responses from other users
   - outgoing questions that you created
   - outgoing responses that you selected
   
The traffic monitor window is cleared each time it is closed because
the report can grow quickly.

}
}

proc help_members {} {

   .help.top.textwin insert 0.0 \
{The Members window displays the current members of this MPoll
session.  The membership list is updated periodically and should be
a good indication of who is currently running MPoll for this session.

The "Keep All" option button causes all members to be displayed in
this  window, even if they are no longer using the session.  Members
no longer using the session are listed in gray text.

}
}

proc help_log {} {

   .help.top.textwin insert 0.0 \
{This logging window displays debugging information.

}
}


