/*  @(#)submit.c	1.5  97/12/23  */

/*
 * Copyright (c) Communications Research Centre, Government of Canada 1997. 
 * All rights reserved.
 * 
 * License is granted to copy and use this software, for research and
 * evaluation purposes, provided that the Communications Research Centre
 * is acknowledged in all documentation pertaining to any such copy or
 * use. The Communications Research Centre grants no other licenses
 * expressed or implied. Title, ownership rights, and intellectual
 * property rights in the software shall remain with the Communications
 * Research Centre.  The Centre's name and the Government of Canada
 * should not be used in any advertising without written permission.
 * 
 * THE COMMUNICATIONS RESEARCH CENTRE MAKES NO REPRESENTATIONS CONCERNING
 * EITHER THE MERCHANTABILITY OF THIS SOFTWARE OR THE SUITABILITY OF
 * THIS SOFTWARE FOR ANY PARTICULAR PURPOSE.  The software is provided
 * "as is" without express or implied warranty of any kind.
 * 
 * These notices must be retained in any copies of any part of this
 * software.
 */


#include "mpoll.h"


/* -------------------------------------------------------------- */
/* handle the submission of a response */

ET_PROC( submit )   
   {
   int currenttopic;
   int curresponse;
   int i, k, numr, foundresponse, myduplicate, gduplicate;
   int butset[MAX_RESPONSES+1];
   char button[1024];
   char *tmpinput = NULL;
   time_t now;
   
   memset(button, 0, sizeof(button));
   memset(butset, 0, sizeof(butset));
   tmpinput = strdup("JUNK"); /* so we are sure we have something to free later */
   
   currenttopic = atoi(argv[1]); /* local copy of the topic number */
   /* printf("On submit, currenttopic is %d\n", currenttopic); */
   
   if (! currenttopic)
      {
      perror("No current topic when submitting response");
      exit(1);
      }
   
   time(&now);
   /* convert time to NTP format for storage */
   now = unixtontp(now);

   /* find out what has been selected in the GUI */
   foundresponse = 0;
   if (strcmp(topiclist[currenttopic].option, "text") == 0)
      {
      tmpinput = strdup(ET_STR(.qmain.butframe.textwin get 1.0 end));
      if (strcmp(tmpinput, "\n") != 0)
         {
         foundresponse = 1;
         removenl(tmpinput);
         }
      }
   else
      {
      for (k = 1; k <= MAX_RESPONSES; k++)
         {
         if (ET_INT(info exists button%d(k)))
            {
            butset[k] = ET_INT(set button%d(k));
            /* printf("button found was %d, value was %d\n", k, butset[k]); */
            if (butset[k] != 0)
               foundresponse++;
            }
         }
      }
         
   
   /* make sure there is something there */
   if (! foundresponse)
      {
      warning("No response button");
      ET(
         tk_dialog .submitdialog \
         "Make a response" \
         "ERROR: Please make a response first" \
         "error" \
         0 \
         "Return"
      );
      free(tmpinput);
      return ET_OK;
      }

   
   myduplicate = 0;
   gduplicate = 0;
   /* check if this is an old response */
   for (i = 1; i <= nummyresponses; i++)
      {
      if (strcmp(myresponse[i].id, topiclist[currenttopic].qid) == 0)
         {
         myduplicate = i;
         }
      }
   
   if (myduplicate)
      {   
      /* find the corresponding global response */
      for (i = 1; i <= numresponses; i++)
         {
         if (
            (strcmp(myresponse[myduplicate].id, responselist[i].id) == 0) &&
            (strcmp(myresponse[myduplicate].user, responselist[i].user) == 0) &&
            (strcmp(myresponse[myduplicate].address, responselist[i].address) == 0)
            ) 
            {
            gduplicate = i;
            }
         }

      /* update my responses */
      myresponse[myduplicate].id = strdup(topiclist[currenttopic].qid);
      myresponse[myduplicate].theme = strdup(topiclist[currenttopic].theme);
      myresponse[myduplicate].version = now;
      myresponse[myduplicate].user = strdup(username);
      myresponse[myduplicate].address = strdup(hostip);
      /* clear out all previous responses */
      for (k = 1; k <= MAX_RESPONSES; k++)
         {
         myresponse[myduplicate].response[k] = NULL;
         }

      /* of not a text response */
      if (strcmp(topiclist[currenttopic].option, "text") == 0)
         {
         myresponse[myduplicate].response[1] = strdup(tmpinput);
         }
      else
         {
         numr = 0;
         for (k = 1; k <= MAX_RESPONSES; k++)
            {
            if (butset[k] != 0)
               {
               numr++;
               myresponse[myduplicate].response[numr] = 
                  strdup(topiclist[currenttopic].response[butset[k]]);
               sprintf(messbuf, "%s", topiclist[currenttopic].response[butset[k]]);
               if (strcmp(button, "") != 0)
                  strcat(button, " ");
               strcat(button, messbuf);
               }
            }
         }
         
      myresponse[myduplicate].time = now;

      /* update all responses */
      memcpy(&responselist[gduplicate], &myresponse[myduplicate], sizeof(struct response));
      send_response_packet(myduplicate);
      }
      
   else /* no duplicate response found */
      {
      nummyresponses++; /* count of my responses */
      curresponse = nummyresponses; /* a new response */

      /* build up a response data structure */
      myresponse[curresponse].id = strdup(topiclist[currenttopic].qid);
      myresponse[curresponse].theme = strdup(topiclist[currenttopic].theme);
      myresponse[curresponse].version = now;
      myresponse[curresponse].user = strdup(username);
      myresponse[curresponse].address = strdup(hostip);
      
      /* if not a text response */
      if (strcmp(topiclist[currenttopic].option, "text") == 0)
         {
         myresponse[curresponse].response[1] = strdup(tmpinput);
         }
      else
         {
         numr = 0;
         for (k = 1; k <= MAX_RESPONSES; k++)
            {
            if (butset[k] != 0)
               {
               numr++;
               myresponse[curresponse].response[numr] = strdup(topiclist[currenttopic].response[butset[k]]);
               sprintf(messbuf, "%s", topiclist[currenttopic].response[butset[k]]);
               if (strcmp(button, "") != 0)
                  strcat(button, " ");
               strcat(button, messbuf);
               }
            }
         }
      myresponse[curresponse].time = now;

      /* my responses count in the total to so... */
      /* add it to the global list of responses and update data */
      numresponses++;
      memcpy(&responselist[numresponses], &myresponse[curresponse], sizeof(struct response));

      /* send it to the world */
      send_response_packet(curresponse);
      }
   
   /* update the cache file */
   writedata();
   
   /* pop up a confirm window for a while */
   
   /* make sure there is nothing there first */
   if (ET_INT(winfo exists .subpop) != 0)
      {
      ET(destroy .subpop);
      }
      
   if (strcmp(topiclist[currenttopic].option, "text") == 0)
      {
      strcpy(button, tmpinput);
      }

   
   ET(
      toplevel .subpop 
      wm title .subpop "Response OK"
      frame .subpop.f -relief groove -borderwidth 2
      message .subpop.f.m -width 300 -text "Your responses of \"%q(button)\" have been submitted.  You may change it anytime by selecting a different response and submitting it again."
      button .subpop.f.but -text Dismiss -command "destroy .subpop"
      pack .subpop.f
      pack .subpop.f.m -side top
      pack .subpop.f.but -side top -fill x -expand true
      after 5000 "catch {destroy .subpop}"
   );
   
   free(tmpinput);
   return ET_OK;
   }

